@@ -94,6 +94,19 @@ def render(
     obj = read(file)
     console.print(build(obj))
 
+@app.command(name='convert', help='Convert Markup Language file 📂 into a JSON file 📄.')
+def convert(
+    file: Union[str, Path] = typer.Argument(..., help='The file to render as a tree.'),
+    to: str = typer.Option('json', '-to', '--convert-to', help='The file extension to convert to.'),
+    ):
+    """Render a Markup Language file 📂 to convert."""
+    obj = read(file)
+    to = to if to.startswith('.') else f'.{to}'
+    to = to.lower()
+    destfile = Path(file).with_suffix(to)
+    write(obj, file)
+    console.print(f'[bold green]Converted [underline]{file}[/] to [underline]{destfile}[/]')
+
 @dev.command(name='check', help='Run checks ❓ on the package 📦')
 def checks():
     """Run checks on the package."""
