@@ -1,5 +1,6 @@
 import rich
 import warnings
+from pathlib import Path
 from itertools import cycle
 
 from typing import Any, Callable, List, Dict, Iterable, Optional, Tuple, Union
@@ -104,7 +105,7 @@ def rich_func(func, *args, **kwargs) -> Any:
     
 def rich_func_chainer(
     funcs: List[Callable], params: List[Any],
-    condition_innerloop: Optional[Callable] = lambda params: False,
+    condition_innerloop: Optional[Callable] = lambda *params: False,
     *args, **kwargs
     ) -> Iterable[Tuple[Union[int, None], Any]]:
     """Run a list of functions with rich progress bar.
@@ -130,7 +131,7 @@ def rich_func_chainer(
     if len(funcs) < len(params):
             funcs = funcs*len(params) if len(funcs) == 1 else cycle(funcs)
     else:
-        warnings.WarningMessage("The number of functions must be < than number of parameters or must be the same.", "Incorrect Value", __file__, 0)
+        warnings.WarningMessage("The number of functions must be < than number of parameters or must be the same.", "Incorrect Value", str(__file__), 0)
     
     progress = kwargs.pop("progress", None)
     console = kwargs.pop("console", None)
@@ -142,7 +143,7 @@ def rich_func_chainer(
         if theme is None:
             progress = Progress(
                 SpinnerColumn(),
-                TextColumn("[bold purple]{task.description}", justify="right"),
+                TextColumn("[bold purple]{task.description}", justify="left"),
                 BarColumn(bar_width=None),
                 "[progress.percentage]{task.percentage:>3.1f}%",
                 TimeElapsedColumn(),
@@ -155,14 +156,26 @@ def rich_func_chainer(
 
     errs = []
     current_loop_task = None
+    
+    fmt_params = []
+    callback_params = []
+    for p in params:
+        if not isinstance(p, Iterable):
+            sp = p.name if isinstance(p, Path) else str(p)
+            fmt_params.append(sp)
+            callback_params.append([p])
+        else:
+            sp = ",".join([x.name if isinstance(x, Path) else str(x) for x in p])
+            fmt_params.append(sp)
+            callback_params.append(p)
 
     with progress:
         main_task = progress.add_task("Running functions", total=len(funcs))
         for i, f in enumerate(funcs):
-            main_loop_task = progress.add_task(f"Running ƒ(●) ≔ {f.__name__}({params[i]})", total=None)
-            if condition_innerloop(*params[i]):
+            main_loop_task = progress.add_task(f"Running ƒ(●) := {f.__name__}({fmt_params[i]})", total=None)
+            if condition_innerloop(*callback_params[i]):
                 if not current_loop_task:
-                    inner_loop_task = progress.add_task(f"Running subquery for {f.__name__}", total=None)
+                    inner_loop_task = progress.add_task(f"Running inner task {f.__name__}", total=None)
                     current_loop_task = inner_loop_task
             else:
                 if current_loop_task:
@@ -170,18 +183,23 @@ def rich_func_chainer(
                     current_loop_task = None
                     progress.update(main_loop_task, complete=True)
                     progress.remove_task(main_loop_task)
-                    main_loop_task = progress.add_task(f"Running ƒ(●) ≔ {f.__name__}({params[i]})", total=None)
+                    main_loop_task = progress.add_task(f"Running ƒ(●) ≔ {f.__name__}({fmt_params[i]})", total=None)
             try:
-                if isinstance(params[i], list):
-                    result = f(*params[i], *args, **kwargs)
-                elif isinstance(params[i], dict):
-                    result = f(*args, **params[i], **kwargs)
+                if isinstance(callback_params[i], list):
+                    result = f(*callback_params[i], *args, **kwargs)
+                elif isinstance(callback_params[i], dict):
+                    result = f(*args, **callback_params[i], **kwargs)
                 else:
-                    result = f(params[i], *args, **kwargs)
+                    result = f(callback_params[i], *args, **kwargs)
                 
                 progress.update(current_loop_task, complete=True) if current_loop_task else None
                 progress.update(main_loop_task, complete=True) if not current_loop_task else None
                 progress.update(main_task, advance=1)
+                progress.remove_task(main_loop_task)
+                progress.remove_task(current_loop_task) if current_loop_task else None
+                progress.refresh()
+
+                yield i, result
 
             except Exception as e:
                 progress.console.print(f"[bold red]Error while running {f.__name__}[/bold red]")
@@ -190,7 +208,6 @@ def rich_func_chainer(
                 progress.update(main_task, advance=1)
                 errs.append(e)
                 yield None, e
-            yield i, result
             
     if errs:
         fmt_errs = '\n - '.join([str(e) for e in errs])
